@@ -9,7 +9,7 @@ use DateTime ();
 use Date::Calc qw(Day_of_Week);
 use List::MoreUtils qw(all any);
 
-our $VERSION = '0.65_01';
+our $VERSION = '0.68_01';
 
 sub new
 {
@@ -60,13 +60,16 @@ sub _init_check
             last;
         }
     }
-    Carp::croak "new(): $error\n" if defined $error;
+    Carp::croak "new(): `$error'" if defined $error;
 
     # time zone can't easily be checked by a regex
     eval {
         DateTime::TimeZone->new(name => $self->{Time_zone});
     };
-    Carp::croak "new(): $@\n" if $@;
+    if ($@) {
+        chomp(my $tz_error = $@);
+        Carp::croak "new(): `$tz_error'";
+    }
 }
 
 sub _init_vars
@@ -90,7 +93,13 @@ sub parse_datetime
     my %count; $count{$_}++ foreach @count;
 
     if (scalar keys %count == 1 && $count{(keys %count)[0]} == 2) {
-        $self->{count}{tokens} = 1;
+        if ($date_string =~ /^\S+\b\s+\b\S+/) {
+            ($date_string, @{$self->{tokens}}) = split /\s+/, $date_string;
+            $self->{count}{tokens} = 1 + @{$self->{tokens}};
+        }
+        else {
+            $self->{count}{tokens} = 1;
+        }
 
         my $separator = quotemeta((keys %count)[0]);
         my @chunks = split /$separator/, $date_string;
@@ -144,6 +153,12 @@ sub parse_datetime
 
         $self->_set_valid_exp;
         $self->_set_modified(1);
+
+        if (@{$self->{tokens} || []}) {
+            $self->_unset_valid_exp;
+            $self->_unset_modified;
+            $self->_process;
+        }
     }
     else {
         @{$self->{tokens}} = split ' ', $date_string;
@@ -439,7 +454,7 @@ DateTime::Format::Natural - Create machine readable date/time with natural parsi
 C<DateTime::Format::Natural> takes a string with a human readable date/time and creates a
 machine readable one by applying natural parsing logic.
 
-=head1 METHODS
+=head1 CONSTRUCTOR
 
 =head2 new
 
@@ -485,6 +500,8 @@ selectively changed.
 
 =back
 
+=head1 METHODS
+
 =head2 parse_datetime
 
 Creates a C<DateTime> object from a human readable date/time string.
